@@ -22,10 +22,14 @@
  *
  */
 
-/*
- * @file hildon-hvolumebar.c
- *
- * This file contains API implementation for Hildon horizontal volumebar.
+/**
+ * SECTION:hildon-hvolumebar
+ * @short_description: A widget that displays a horizontal volume bar
+ * @see_also: #HildonVVolumebar, #HildonVolumebar
+ * 
+ * The #HildonHVolumebar widget displays a horizontal volume bar that allows
+ * increasing or decreasing volume within a pre-defined range, and includes 
+ * a mute icon which users can click to mute the sound.
  */
 
 
@@ -38,29 +42,32 @@
 #include "hildon-volumebar-private.h"
 
 /* Defines for normal version of HVolumebar */
+/* Toggle button */
 #define DEFAULT_TBUTTON_WIDTH  26
 #define DEFAULT_TBUTTON_HEIGHT 26
+/* Volume bar */
 #define MINIMUM_BAR_WIDTH     147
 #define DEFAULT_BAR_HEIGHT     58
 #define DEFAULT_ENDING_SIZE    20
 
+/* Gap to leave for mute button */
 #define VERTICAL_MUTE_GAP      16
 #define HORIZONTAL_MUTE_GAP     6
 
+/* Sizes inside a toolbar */
+/* Toggle button */
 #define TOOL_DEFAULT_TBUTTON_WIDTH  26
 #define TOOL_DEFAULT_TBUTTON_HEIGHT 26
+/* Volumebar */
 #define TOOL_MINIMUM_BAR_WIDTH     121
 #define TOOL_DEFAULT_BAR_HEIGHT     40
 #define TOOL_DEFAULT_ENDING_SIZE     0
 #define TOOL_VERTICAL_MUTE_GAP ((TOOL_DEFAULT_BAR_HEIGHT - TOOL_DEFAULT_TBUTTON_HEIGHT) / 2)
 
 static HildonVolumebarClass *parent_class;
-static void hvolumebar_class_init(HildonHVolumebarClass * klass);
-static void hvolumebar_init(HildonHVolumebar * hvolumebar);
-static void
-hildon_hvolumebar_mute(GtkWidget * widget, HildonHVolumebar * self);
+static void hildon_hvolumebar_class_init(HildonHVolumebarClass * klass);
+static void hildon_hvolumebar_init(HildonHVolumebar * hvolumebar);
 
-/* new */
 static gboolean hildon_hvolumebar_expose(GtkWidget * widget,
                                          GdkEventExpose * event);
 static void hildon_hvolumebar_size_request(GtkWidget * widget,
@@ -79,12 +86,12 @@ GType hildon_hvolumebar_get_type(void)
             sizeof(HildonHVolumebarClass),
             NULL,       /* base_init */
             NULL,       /* base_finalize */
-            (GClassInitFunc) hvolumebar_class_init,     /* class_init */
+            (GClassInitFunc) hildon_hvolumebar_class_init,     /* class_init */
             NULL,       /* class_finalize */
             NULL,       /* class_data */
             sizeof(HildonHVolumebar),
             0,
-            (GInstanceInitFunc) hvolumebar_init,
+            (GInstanceInitFunc) hildon_hvolumebar_init,
         };
         type = g_type_register_static(HILDON_TYPE_VOLUMEBAR,
                                       "HildonHVolumebar", &info, 0);
@@ -93,7 +100,7 @@ GType hildon_hvolumebar_get_type(void)
 }
 
 
-static void hvolumebar_class_init(HildonHVolumebarClass * klass)
+static void hildon_hvolumebar_class_init(HildonHVolumebarClass * klass)
 {
     GtkWidgetClass *volumebar_class = GTK_WIDGET_CLASS(klass);
 
@@ -106,24 +113,20 @@ static void hvolumebar_class_init(HildonHVolumebarClass * klass)
 }
 
 
-static void hvolumebar_init(HildonHVolumebar * hvolumebar)
+static void hildon_hvolumebar_init(HildonHVolumebar * hvolumebar)
 {
-    HildonVolumebar *v_ptr = HILDON_VOLUMEBAR(hvolumebar);
     HildonVolumebarPrivate *priv;
 
     priv = HILDON_VOLUMEBAR_GET_PRIVATE(hvolumebar);
 
-    priv->ownorientation = GTK_ORIENTATION_HORIZONTAL;
-    priv->orientation = GTK_ORIENTATION_HORIZONTAL;
-
     priv->volumebar =
         HILDON_VOLUMEBAR_RANGE(hildon_volumebar_range_new
                                (GTK_ORIENTATION_HORIZONTAL));
 
     GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(hvolumebar), GTK_CAN_FOCUS);
 
-    gtk_widget_set_parent(GTK_WIDGET(priv->tbutton), GTK_WIDGET(v_ptr));
-    gtk_widget_set_parent(GTK_WIDGET(priv->volumebar), GTK_WIDGET(v_ptr));
+    gtk_widget_set_parent(GTK_WIDGET(priv->tbutton), GTK_WIDGET(hvolumebar));
+    gtk_widget_set_parent(GTK_WIDGET(priv->volumebar), GTK_WIDGET(hvolumebar));
 
     gtk_scale_set_draw_value(GTK_SCALE(priv->volumebar), FALSE);
 
@@ -131,10 +134,9 @@ static void hvolumebar_init(HildonHVolumebar * hvolumebar)
     g_signal_connect_swapped(G_OBJECT(priv->volumebar), "value-changed",
                              G_CALLBACK(hildon_volumebar_level_change),
                              hvolumebar);
-    g_signal_connect(G_OBJECT(priv->tbutton), "toggled",
-                     G_CALLBACK(hildon_hvolumebar_mute), hvolumebar);
+    g_signal_connect_swapped(priv->tbutton, "toggled",
+        G_CALLBACK(_hildon_volumebar_mute_toggled), hvolumebar);
 
-    /*gtk_widget_show(GTK_WIDGET(priv->tbutton));*/
     gtk_widget_show(GTK_WIDGET(priv->volumebar));
 }
 
@@ -143,24 +145,24 @@ static void hvolumebar_init(HildonHVolumebar * hvolumebar)
  *
  * Creates a new #HildonHVolumebar widget.
  *
- * Returns: a new #HildonHVolumebar.
+ * Returns: a new #HildonHVolumebar
  */
-GtkWidget *hildon_hvolumebar_new()
+GtkWidget *hildon_hvolumebar_new(void)
 {
     return GTK_WIDGET(g_object_new(HILDON_TYPE_HVOLUMEBAR, NULL));
 }
 
 static void hildon_hvolumebar_map(GtkWidget * widget)
 {
-    HildonVolumebar *vbar;
     HildonVolumebarPrivate *priv;
     GtkWidget *parent;
 
-    vbar = HILDON_VOLUMEBAR(widget);
-    priv = HILDON_VOLUMEBAR_GET_PRIVATE(vbar);
+    g_assert(HILDON_IS_HVOLUMEBAR(widget));
 
+    priv = HILDON_VOLUMEBAR_GET_PRIVATE(widget);
     parent = gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_TOOLBAR);
 
+    /* Check if the volumebar is in a toolbar */
     if (parent)
         priv->is_toolbar = TRUE;
 
@@ -171,9 +173,13 @@ static gboolean hildon_hvolumebar_expose(GtkWidget * widget,
                                          GdkEventExpose * event)
 {
     HildonVolumebarPrivate *priv;
+
+    g_assert(HILDON_IS_HVOLUMEBAR(widget));
+
     priv = HILDON_VOLUMEBAR_GET_PRIVATE(HILDON_VOLUMEBAR(widget));
-    
+
     if (GTK_WIDGET_DRAWABLE(widget)) {
+        /* Paint background */
         gtk_paint_box(widget->style, widget->window,
                       GTK_WIDGET_STATE(priv->volumebar), GTK_SHADOW_OUT,
                       NULL, widget, "background",
@@ -182,6 +188,7 @@ static gboolean hildon_hvolumebar_expose(GtkWidget * widget,
                       widget->allocation.width,
                       widget->allocation.height);
 
+	/* The contents of the widget can paint themselves */
         (*GTK_WIDGET_CLASS(parent_class)->expose_event) (widget, event);
     }
 
@@ -194,8 +201,11 @@ hildon_hvolumebar_size_request(GtkWidget * widget,
 {
     HildonVolumebarPrivate *priv;
 
+    g_assert(HILDON_IS_HVOLUMEBAR(widget));
+
     priv = HILDON_VOLUMEBAR_GET_PRIVATE(HILDON_VOLUMEBAR(widget));
 
+    /* Volumebar has different dimensions in toolbar */
     requisition->width = (priv->is_toolbar
                           ? TOOL_MINIMUM_BAR_WIDTH
                           : MINIMUM_BAR_WIDTH);
@@ -208,21 +218,21 @@ static void
 hildon_hvolumebar_size_allocate(GtkWidget * widget,
                                 GtkAllocation * allocation)
 {
-    HildonVolumebar *vbar;
     HildonVolumebarPrivate *priv;
     GtkAllocation button_allocation, range_allocation;
 
-    vbar = HILDON_VOLUMEBAR(widget);
-    priv = HILDON_VOLUMEBAR_GET_PRIVATE(vbar);
+    g_assert(HILDON_IS_HVOLUMEBAR(widget));
+
+    priv = HILDON_VOLUMEBAR_GET_PRIVATE(widget);
     
     button_allocation.x = 0;
     button_allocation.width = 0;
     
+    /* Center the widget vertically */
     if (priv->is_toolbar && allocation->height > TOOL_DEFAULT_BAR_HEIGHT) {
         allocation->y += (allocation->height - TOOL_DEFAULT_BAR_HEIGHT) / 2;
         allocation->height = TOOL_DEFAULT_BAR_HEIGHT;
     }
-
     if (!priv->is_toolbar && allocation->height > DEFAULT_BAR_HEIGHT) {
         allocation->y += (allocation->height - DEFAULT_BAR_HEIGHT) / 2;
         allocation->height = DEFAULT_BAR_HEIGHT;
@@ -232,6 +242,7 @@ hildon_hvolumebar_size_allocate(GtkWidget * widget,
 
     if (priv->tbutton && GTK_WIDGET_VISIBLE(priv->tbutton)) {
 
+        /* Allocate space for the mute button */
         if (priv->is_toolbar) {
             button_allocation.x = allocation->x;
             button_allocation.y = allocation->y + TOOL_VERTICAL_MUTE_GAP;
@@ -248,16 +259,19 @@ hildon_hvolumebar_size_allocate(GtkWidget * widget,
     }
     if (priv->volumebar && GTK_WIDGET_VISIBLE(priv->volumebar)) {
 
+        /* Allocate space for the slider */
         range_allocation.y = allocation->y;
         
         if (priv->tbutton && GTK_WIDGET_VISIBLE(priv->tbutton))
         {
+	    /* Leave room for the mute button */
             range_allocation.x = button_allocation.x
                                  + button_allocation.width
                                  + HORIZONTAL_MUTE_GAP;
         
             if (priv->is_toolbar) 
             {
+	        /* In toolbar with mute button */
                 range_allocation.width = MAX(0,
                                            allocation->width
                                            - 2 * TOOL_DEFAULT_ENDING_SIZE
@@ -270,6 +284,7 @@ hildon_hvolumebar_size_allocate(GtkWidget * widget,
             
             else 
             {
+	        /* Standalone with mute button */
                 range_allocation.width = MAX(0,
                                              allocation->width
                                              - 2 * DEFAULT_ENDING_SIZE
@@ -285,6 +300,7 @@ hildon_hvolumebar_size_allocate(GtkWidget * widget,
         {
             if (priv->is_toolbar) 
             {
+                /* In toolbar without mute button */
                 range_allocation.x = allocation->x;
                 
                 range_allocation.width = MAX(0,
@@ -297,7 +313,7 @@ hildon_hvolumebar_size_allocate(GtkWidget * widget,
             
             else 
             {
-                
+                /* Standalone without mute button */
                 range_allocation.x = allocation->x + DEFAULT_ENDING_SIZE;
                 
                 range_allocation.width = MAX(0,
@@ -312,9 +328,3 @@ hildon_hvolumebar_size_allocate(GtkWidget * widget,
                                  &range_allocation);
     }
 }
-
-static void
-hildon_hvolumebar_mute(GtkWidget * widget, HildonHVolumebar * self)
-{
-    g_signal_emit_by_name(GTK_WIDGET(self), "mute_toggled");
-}
