@@ -22,24 +22,21 @@
  *
  */
 
-/* 
- * @file hildon-set-password-dialog.c
+/**
+ * SECTION:hildon-set-password-dialog
+ * @short_description: A dialog used to set, change or remove a password
+ * @see_also: #HildonGetPasswordDialog
  *
- * This file implements API for Hildon Set and Change Password dialog.
+ * HildonSetPasswordDialog allows setting and changing a password. 
  * 
- *  Change password dialog:
- *   @desc: Change Password Dialog is used to change an existing one in
- *   situtations where the password can be removed. Unselecting the check
- *   box dims the password fields below it. If the dialog is accepted with
- *   'OK' while the check box is unselected, a Confirmation Note is played.
- *   If a Confirmation Note Dialog is accepted with 'Remove', the password
- *   protection is removed.  
+ * In Change mode: Dialog is used to change or remove an existing
+ * password. Unselecting the check box dims the password fields below
+ * it. If the dialog is accepted with 'OK' while the check box is
+ * unselected, a Confirmation Note is shown.  If the Confirmation Note
+ * Dialog is accepted with 'Remove', the password protection is removed.  
  * 
- *  Set password dialog:
- *   @desc: Set Password Dialog is used to define a password, or change a
- *   password that cannot be removed.
- *   @seealso: #HildonGetPasswordDialog
- *
+ * In Set mode: Set Password Dialog is used to define a password, or
+ * change a password that cannot be removed.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,7 +61,8 @@
 #include <hildon-widgets/hildon-defines.h>
 
 #include <libintl.h>
-#define _(String) dgettext(PACKAGE, String)
+#define  _(String) dgettext(PACKAGE, String)
+#define c_(String) dgettext("hildon-common-strings", String)
 
 static GtkDialogClass *parent_class;
 
@@ -80,20 +78,14 @@ hildon_set_password_dialog_class_init(HildonSetPasswordDialogClass *
                                       class);
 static void hildon_set_password_dialog_init(HildonSetPasswordDialog *
                                             dialog);
-static void hildon_checbox_toggled(GtkWidget * widget, gpointer data);
+static void hildon_checkbox_toggled(GtkWidget * widget, gpointer dialog);
 
 static void
-hildon_set_password_response_change(GtkDialog * d, gint arg1,
-                                    GtkWindow * parent);
+hildon_set_password_response_change(GtkDialog * d, gint arg1, gpointer unused);
 static void
-hildon_set_password_response_set(GtkDialog * d, gint arg1,
-                                 GtkWindow * parent);
+hildon_set_password_response_set(GtkDialog * d, gint arg1, gpointer unused);
 
-static GObject *
-hildon_set_password_dialog_constructor(GType type,
-                                       guint n_construct_properties,
-                                       GObjectConstructParam *
-                                       construct_properties);
+static void create_contents(HildonSetPasswordDialog *dialog);
 static void hildon_set_password_set_property(GObject * object,
                                              guint prop_id,
                                              const GValue * value,
@@ -103,30 +95,24 @@ static void hildon_set_password_get_property(GObject * object,
                                              GParamSpec * pspec);
 
 /* Private struct */
-
 struct _HildonSetPasswordDialogPrivate {
-    /* Checkbox tab */
     GtkWidget *checkboxCaption;
     GtkWidget *checkbox;
 
     GtkLabel *domainLabel;
 
-    /* Tab one */
     GtkWidget *pwd1stEntry;
     GtkWidget *pwd1stCaption;
     gchar *pwd1stCaption_string;
 
-    /* Tab two */
     GtkWidget *pwd2ndEntry;
     GtkWidget *pwd2ndCaption;
     gchar *pwd2ndCaption_string;
 
-    /* OK/Cancel buttons */
     GtkWidget *okButton;
     GtkWidget *cancelButton;
 
     gboolean protection;
-
 };
 
 enum {
@@ -149,13 +135,19 @@ hildon_set_password_set_property(GObject * object,
     
     switch (prop_id) {
     case PROP_DOMAIN:
+        /* Update domain label to display new value */
         gtk_label_set_text(priv->domainLabel, g_value_get_string(value));
 	break;
     case PROP_PASSWORD:
+        /* Update password entry to display new value */
         gtk_entry_set_text(GTK_ENTRY(priv->pwd1stEntry), g_value_get_string(value));
         break;
     case PROP_HILDON_PASSWORD_DIALOG:
+        /* Note this is a G_PARAM_CONSTRUCT_ONLY type property */
         priv->protection = g_value_get_boolean(value);
+
+	/* We now have the necessary information to populate the dialog */
+	create_contents(dialog);
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -164,26 +156,25 @@ hildon_set_password_set_property(GObject * object,
 }
 
 static void
-hildon_set_password_get_property(GObject * object,
-                                 guint prop_id,
-                                 GValue * value, GParamSpec * pspec)
+hildon_set_password_get_property(GObject    * object,
+                                 guint        prop_id,
+                                 GValue     * value,
+                                 GParamSpec * pspec)
 {
-    HildonSetPasswordDialog *dialog = HILDON_SET_PASSWORD_DIALOG(object);
-    HildonSetPasswordDialogPrivate *priv;
-    const gchar *string;
+    HildonSetPasswordDialogPrivate *priv = NULL;
 
-    priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
+    priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(object);
     
     switch (prop_id) {
     case PROP_DOMAIN:
-        string = gtk_label_get_text(priv->domainLabel);
-        g_value_set_string(value, string);
+        g_value_set_string(value, gtk_label_get_text(priv->domainLabel));
+	break;
     case PROP_PASSWORD:
-        string = gtk_entry_get_text(GTK_ENTRY(priv->pwd1stEntry));
-        g_value_set_string(value, string);
+        g_value_set_string(value,
+			   gtk_entry_get_text(GTK_ENTRY(priv->pwd1stEntry)));
         break;
     case PROP_HILDON_PASSWORD_DIALOG:
-        g_value_set_boolean(value, g_value_get_boolean(value));
+        g_value_set_boolean(value, priv->protection);
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -191,105 +182,92 @@ hildon_set_password_get_property(GObject * object,
     }
 }
 
-static GObject *
-hildon_set_password_dialog_constructor(GType type,
-                                       guint n_construct_properties,
-                                       GObjectConstructParam *
-                                       construct_properties)
+
+static void
+create_contents(HildonSetPasswordDialog *dialog)
 {
-    GObject *dialog;
-    GObjectClass *parent_class;
-    HildonSetPasswordDialogPrivate *priv;
+    HildonSetPasswordDialogPrivate *priv = NULL;
+
     GtkSizeGroup *group;
 
-    parent_class = G_OBJECT_CLASS(g_type_class_peek_parent
-                                  (g_type_class_peek(type)));
-    dialog = parent_class->constructor(type, n_construct_properties,
-                                       construct_properties);
-
-    gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
-
     priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
-
     priv->checkbox = NULL;
 
+    /* Size group for labels */
     group = GTK_SIZE_GROUP(gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL));
 
     gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
 
+    /* Setup and pack domain label */
     priv->domainLabel = GTK_LABEL(gtk_label_new(NULL));
-
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
 		       GTK_WIDGET(priv->domainLabel), FALSE, FALSE, 0);
-
     gtk_widget_show(GTK_WIDGET(priv->domainLabel));
 
-
     if (priv->protection == TRUE) {
-        /* create checkbox */
+        /* Use Change Password Dialog strings */
         priv->pwd1stCaption_string = _(HILDON_SET_MODIFY_PASSWORD_DIALOG_PASSWORD);
         priv->pwd2ndCaption_string = _(HILDON_SET_MODIFY_PASSWORD_DIALOG_VERIFY_PASSWORD);
 
+        /* Setup checkbox to enable/disable password protection */
         priv->checkbox = gtk_check_button_new();
-
         gtk_widget_show(priv->checkbox);
-
         priv->checkboxCaption = hildon_caption_new
 	  (group,
 	   _(HILDON_SET_MODIFY_PASSWORD_DIALOG_LABEL),
 	   priv->checkbox,
 	   NULL, HILDON_CAPTION_OPTIONAL);
 	hildon_caption_set_separator(HILDON_CAPTION(priv->checkboxCaption), "");
-
-        gtk_signal_connect(GTK_OBJECT(priv->checkbox), "toggled",
-                           G_CALLBACK(hildon_checbox_toggled), dialog);
-	
         gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
                            priv->checkboxCaption, TRUE, TRUE, 0);
         gtk_widget_show(priv->checkboxCaption);
-
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->checkbox),
                                      TRUE);
-
+        gtk_signal_connect(GTK_OBJECT(priv->checkbox), "toggled",
+                           G_CALLBACK(hildon_checkbox_toggled), dialog);
+ 
+	/* Setup appropriate response handler */
+        g_signal_connect(G_OBJECT(dialog), "response",
+                         G_CALLBACK(hildon_set_password_response_change),
+                         NULL);
     } else {
+        /* Use Set Password Dialog strings */
         priv->pwd1stCaption_string = _(HILDON_SET_PASSWORD_DIALOG_PASSWORD);
         priv->pwd2ndCaption_string = _(HILDON_SET_PASSWORD_DIALOG_VERIFY_PASSWORD);
+
+	/* Setup appropriate response handler */
+        g_signal_connect(G_OBJECT(dialog), "response",
+                         G_CALLBACK(hildon_set_password_response_set),
+                         NULL);
     }
 
-
-    /* create tab1 */
+    /* Create the password field */
     priv->pwd1stEntry = gtk_entry_new();
     gtk_widget_show(priv->pwd1stEntry);
-
     priv->pwd1stCaption = hildon_caption_new(group,
                                         priv->pwd1stCaption_string,
                                         priv->pwd1stEntry,
                                         NULL, HILDON_CAPTION_OPTIONAL);
     hildon_caption_set_separator(HILDON_CAPTION(priv->pwd1stCaption), "");
-
     gtk_entry_set_visibility(GTK_ENTRY(priv->pwd1stEntry), FALSE);
-
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
                        priv->pwd1stCaption, TRUE, TRUE, 0);
     gtk_widget_show(priv->pwd1stCaption);
 
-    /* create tab2 */
+    /* Create the password verify field */
     priv->pwd2ndEntry = gtk_entry_new();
     gtk_widget_show(priv->pwd2ndEntry);
-
     priv->pwd2ndCaption = hildon_caption_new(group,
                                         priv->pwd2ndCaption_string,
                                         priv->pwd2ndEntry,
                                         NULL, HILDON_CAPTION_OPTIONAL);
     hildon_caption_set_separator(HILDON_CAPTION(priv->pwd2ndCaption), "");
-
     gtk_entry_set_visibility(GTK_ENTRY(priv->pwd2ndEntry), FALSE);
-
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
                        priv->pwd2ndCaption, TRUE, TRUE, 0);
-
     gtk_widget_show(priv->pwd2ndCaption);
 
+    /* Set dialog title */
     gtk_window_set_title(GTK_WINDOW(dialog),
                          _(priv->protection
                            ? HILDON_SET_MODIFY_PASSWORD_DIALOG_TITLE
@@ -307,30 +285,25 @@ hildon_set_password_dialog_constructor(GType type,
 			     : HILDON_SET_PASSWORD_DIALOG_CANCEL),
        GTK_RESPONSE_CANCEL);
     
-    /*    gtk_window_resize(GTK_WINDOW(dialog), 370, 110); */
-    /*    remove now, pixel perfection can address these majik thingys */
-
     gtk_widget_show(priv->okButton);
     gtk_widget_show(priv->cancelButton);
 
-
-    return dialog;
+    /* Ensure group is freed when all its contents have been removed */
+    g_object_unref(group);
 }
 
 static void
 hildon_set_password_dialog_class_init(HildonSetPasswordDialogClass * class)
 {
-
-
     GObjectClass *object_class = G_OBJECT_CLASS(class);
 
     parent_class = g_type_class_peek_parent(class);
 
+    /* Override virtual methods */
     object_class->set_property = hildon_set_password_set_property;
     object_class->get_property = hildon_set_password_get_property;
-    object_class->constructor = hildon_set_password_dialog_constructor;
-
 
+    /* Install new properties */
     g_object_class_install_property(object_class, 
 		     PROP_DOMAIN, 
 		     g_param_spec_string ("domain",
@@ -356,106 +329,124 @@ hildon_set_password_dialog_class_init(HildonSetPasswordDialogClass * class)
 					  "DEFAULT",
 					  G_PARAM_READWRITE));
 
+    /* Install private structure */
     g_type_class_add_private(class,
                              sizeof(HildonSetPasswordDialogPrivate));
 }
 
-
 static void
 hildon_set_password_dialog_init(HildonSetPasswordDialog * dialog)
 {
-    HildonSetPasswordDialogPrivate *priv;
+    /* Most of the initializations are done in create_contents()
+       after the 'modify_protection' property has been set */
 
-    priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
-
-    priv->protection = FALSE;
+    gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
 }
 
+
+/* We come here when response button is clicked and dialog 
+   is used to change existing password. */
 static void
 hildon_set_password_response_change(GtkDialog * dialog, gint arg1,
-                                    GtkWindow * parent)
+                                    gpointer unused)
 {
     GtkEntry *pwd1stEntry;
     GtkEntry *pwd2ndEntry;
     gchar *text1;
     gchar *text2;
-
     HildonNote *note;
     gint i;
-
     HildonSetPasswordDialogPrivate *priv;
 
     priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
 
+    /* Password and verification */
     pwd1stEntry = GTK_ENTRY(gtk_bin_get_child
 			    (GTK_BIN(priv->pwd1stCaption)));
-
     pwd2ndEntry = GTK_ENTRY(gtk_bin_get_child
 			    (GTK_BIN(priv->pwd2ndCaption)));
-
     text1 = GTK_ENTRY(pwd1stEntry)->text;
     text2 = GTK_ENTRY(pwd2ndEntry)->text;
+
+    /* User accepted the dialog */
     if (arg1 == GTK_RESPONSE_OK){
+      /* Is the checkbox marked, so password protection is still in use? */  
       if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(priv->checkbox))){
-	if(strcmp(text1, "" ) != 0){
-	  if(strcmp (text1, text2) == 0){
+    /* Yes, Something is given as password as well? */
+	if (text1[0] != '\0') {
+	  if (strcmp (text1, text2) == 0) {
+	    /* Passwords match, so accept change password */
 	    priv->protection = TRUE;
-	  } else if(strcmp(text2, "" ) == 0){
+	  } else if (text2[0] == '\0') {
+	    /* Second field is empty, so show error, but don't clear fields */
 	    g_signal_stop_emission_by_name(G_OBJECT(dialog),
 					   "response");
 	    gtk_infoprint (NULL,
-			   _(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
+			   c_(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
 	    gtk_widget_grab_focus(GTK_WIDGET(pwd2ndEntry));
-	  } else{
+	  } else {
+	    /* Error: Passwords don't match, so start over */
 	    g_signal_stop_emission_by_name(G_OBJECT(dialog),
 					   "response");
 	    gtk_entry_set_text(pwd1stEntry, "");
 	    gtk_entry_set_text(pwd2ndEntry, "");
 	    gtk_infoprint (NULL,
-			   _(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
+			   c_(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
 	    gtk_widget_grab_focus(GTK_WIDGET(pwd1stEntry));
 	  }
 	} else {
+	  /* No, the password is empty */
 	  g_signal_stop_emission_by_name(G_OBJECT(dialog), "response");
-	  if (strcmp(text2, "") == 0) {
-	    gtk_infoprint (NULL, _(HILDON_SET_PASSWORD_DIALOG_EMPTY));
+	  if (text2[0] == '\0') {
+	    /* Error: Both fields are empty */
+	    gtk_infoprint (NULL, c_(HILDON_SET_PASSWORD_DIALOG_EMPTY));
 	  } else {
-	    gtk_infoprint (NULL, _(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
+	    /* Error: Second field doesn't match
+	       the empty first field, so start over */
+	    gtk_infoprint (NULL, c_(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
 	    gtk_entry_set_text(pwd2ndEntry, "");
 	  }
 	  gtk_widget_grab_focus(GTK_WIDGET(pwd1stEntry));
 	}
-      } else{
+      } else {
+        /* No, user wants to remove password protection. 
+           Confirm remove password protection */
 	note = HILDON_NOTE(hildon_note_new_confirmation
 			   (GTK_WINDOW(dialog),
-			    _(HILDON_SET_PASSWORD_DIALOG_REMOVE_PROTECTION
+			    c_(HILDON_SET_PASSWORD_DIALOG_REMOVE_PROTECTION
 			      )));
       
 	hildon_note_set_button_texts
 	  (HILDON_NOTE(note),
-	   _(HILDON_REMOVE_PROTECTION_CONFIRMATION_REMOVE), 
-	   _(HILDON_REMOVE_PROTECTION_CONFIRMATION_CANCEL));
+	   c_(HILDON_REMOVE_PROTECTION_CONFIRMATION_REMOVE), 
+	   c_(HILDON_REMOVE_PROTECTION_CONFIRMATION_CANCEL));
 	
+        /* Display confirmation note */
 	i = gtk_dialog_run(GTK_DIALOG(note));
 	
 	gtk_widget_destroy(GTK_WIDGET(note));
 	
 	if (i == GTK_RESPONSE_OK)
+	  /* Remove password protection */
 	  priv->protection = FALSE;
 	else {
+	  /* Remove password protection cancelled */
 	  priv->protection = TRUE;
 	  g_signal_stop_emission_by_name(G_OBJECT(dialog), "response");
 	}
       }
 
     } else {
+      /* Watch out for fading boolean values */
       priv->protection = TRUE;
     }
 }
 
+/* We come here when response button is clicked and dialog 
+   is used to set new password. */
 static void
 hildon_set_password_response_set(GtkDialog * dialog, gint arg1,
-                                 GtkWindow * parent)
+                                 gpointer unused)
 {
     GtkEntry *pwd1stEntry;
     GtkEntry *pwd2ndEntry;
@@ -466,60 +457,65 @@ hildon_set_password_response_set(GtkDialog * dialog, gint arg1,
 
     priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
 
+    /* Password and confirmation */
     pwd1stEntry = GTK_ENTRY(gtk_bin_get_child
 			    (GTK_BIN(priv->pwd1stCaption)));
-
     pwd2ndEntry = GTK_ENTRY(gtk_bin_get_child
 			    (GTK_BIN(priv->pwd2ndCaption)));
-
     text1 = GTK_ENTRY(pwd1stEntry)->text;
     text2 = GTK_ENTRY(pwd2ndEntry)->text;
 
     if (arg1 == GTK_RESPONSE_OK) {
-        if (strcmp (text1, "") != 0) {
+        /* User provided something for password? */
+        if (text1[0] != '\0') {
             if (strcmp (text1, text2) == 0) {
+	        /* Passwords match, so accept set password */
                 priv->protection = TRUE;
-            } else if (strcmp (text2, "") == 0) {
+            } else if (text2[0] == '\0') {
+                /* Second field is empty, so show error,
+                   but don't clear the fields */
                 g_signal_stop_emission_by_name(G_OBJECT(dialog), "response");
-                gtk_infoprint (NULL, _(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
+                gtk_infoprint (NULL, c_(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
                 gtk_widget_grab_focus (GTK_WIDGET (priv->pwd2ndEntry));
             } else {
+                /* Error: Passwords don't match, so start over */
                 g_signal_stop_emission_by_name(G_OBJECT(dialog), "response");
 	        gtk_entry_set_text(pwd1stEntry, "");
 		gtk_entry_set_text(pwd2ndEntry, "");
-	        gtk_infoprint (NULL, _(HILDON_SET_PASSWORD_DIALOG_MISMATCH ));
+	        gtk_infoprint (NULL, c_(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
                 gtk_widget_grab_focus(GTK_WIDGET(priv->pwd1stEntry));
 	    }
         } else {
-            g_signal_stop_emission_by_name(G_OBJECT(dialog), "response");
-	  if (strcmp(text2, "") == 0) {
-	    gtk_infoprint (NULL, _(HILDON_SET_PASSWORD_DIALOG_EMPTY));
+          /* First field is empty */
+          g_signal_stop_emission_by_name(G_OBJECT(dialog), "response");
+	  if (text2[0] == '\0') {
+	    /* Error: Both fields are empty */
+	    gtk_infoprint (NULL, c_(HILDON_SET_PASSWORD_DIALOG_EMPTY));
 	  } else {
-	    gtk_infoprint (NULL, _(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
+	    /* Error: Second field doesn't match
+	       the empty first field, so start over */
+	    gtk_infoprint (NULL, c_(HILDON_SET_PASSWORD_DIALOG_MISMATCH));
 	    gtk_entry_set_text(pwd2ndEntry, "");
 	  }
 	  gtk_widget_grab_focus(GTK_WIDGET(pwd1stEntry));
         }
     } else { 
+        /* Watch out for fading boolean values */
         priv->protection = FALSE;
     }    	  
 }
 
-static void hildon_checbox_toggled(GtkWidget * widget, gpointer data)
+static void hildon_checkbox_toggled(GtkWidget * widget, gpointer dialog)
 {
-    HildonSetPasswordDialog *dialog;
-    HildonSetPasswordDialogPrivate *priv;
+    HildonSetPasswordDialogPrivate *priv =
+      HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
+    gboolean active;
 
-    dialog = HILDON_SET_PASSWORD_DIALOG(data);
-    priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
-
-    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
-        gtk_widget_set_sensitive(GTK_WIDGET(priv->pwd1stEntry), TRUE);
-        gtk_widget_set_sensitive(GTK_WIDGET(priv->pwd2ndEntry), TRUE);
-    } else {
-        gtk_widget_set_sensitive(GTK_WIDGET(priv->pwd1stEntry), FALSE);
-        gtk_widget_set_sensitive(GTK_WIDGET(priv->pwd2ndEntry), FALSE);
-    }
+    /* If the user enabled/disabled the password protection feature
+       we enable/disable password entries accordingly */
+    active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+    gtk_widget_set_sensitive(GTK_WIDGET(priv->pwd1stEntry), active);
+    gtk_widget_set_sensitive(GTK_WIDGET(priv->pwd2ndEntry), active);
 }
 
 /* Public functions */
@@ -530,9 +526,9 @@ static void hildon_checbox_toggled(GtkWidget * widget, gpointer data)
  * Returns GType for HildonPasswordDialog as produced by
  * g_type_register_static().
  *
- * Return value: HildonSetPasswordDialog type
- **/
-GType hildon_set_password_dialog_get_type()
+ * Returns: HildonSetPasswordDialog type
+ */
+GType hildon_set_password_dialog_get_type(void)
 {
     static GType dialog_type = 0;
 
@@ -562,59 +558,44 @@ GType hildon_set_password_dialog_get_type()
  * @modify_protection: TRUE creates a new change password dialog and FALSE
  *                     creates a new set password dialog 
  * 
- * Construct a new HildonSetPasswordDialog.
+ * Constructs a new HildonSetPasswordDialog.
  *
- * Return value: a new #GtkWidget of type HildonSetPasswordDialog
- **/
+ * Returns: a new #GtkWidget of type HildonSetPasswordDialog
+ */
 
 GtkWidget *hildon_set_password_dialog_new(GtkWindow * parent,
                                           gboolean modify_protection)
 {
-    GtkWidget *dialog = g_object_new
-        (HILDON_TYPE_SET_PASSWORD_DIALOG, "modify_protection",
-         modify_protection, NULL);
-
-    if (modify_protection == TRUE) {
-        g_signal_connect(G_OBJECT(dialog), "response",
-                         G_CALLBACK(hildon_set_password_response_change),
-                         parent);
-    } else {
-        g_signal_connect(G_OBJECT(dialog), "response",
-                         G_CALLBACK(hildon_set_password_response_set),
-                         parent);
-    }
-    if (parent != NULL) {
-        gtk_window_set_transient_for(GTK_WINDOW(dialog), parent);
-    }
-
-    return dialog;
+    return hildon_set_password_dialog_new_with_default(parent, "",
+						       modify_protection);
 }
 
 /**
  * hildon_set_password_dialog_new_with_default:
  * @parent: parent window; can be NULL
- * @password: a default password to be shown in password field.
+ * @password: a default password to be shown in password field
  * @modify_protection: TRUE creates a new change password dialog and FALSE
  *                     creates a new set password dialog 
  * 
  * Same as #hildon_set_password_dialog_new, but with a default password
  * in password field.
  *
- * Return value: a new #GtkWidget of type HildonSetPasswordDialog
- **/
+ * Returns: a new #GtkWidget of type HildonSetPasswordDialog
+ */
 
 GtkWidget *hildon_set_password_dialog_new_with_default
                                          (GtkWindow *parent,
-					  gchar *password,
+					  const gchar *password,
                                           gboolean modify_protection)
 {
-    GtkWidget *dialog;
+    GtkWidget *dialog = g_object_new(HILDON_TYPE_SET_PASSWORD_DIALOG,
+				     "modify_protection", modify_protection,
+				     "password", password, NULL);
 
-    dialog = hildon_set_password_dialog_new(parent, 
-					    modify_protection);
-    if(password != NULL)
-        g_object_set(G_OBJECT(dialog), "password", password, NULL);
-    
+    if (parent != NULL) {
+        gtk_window_set_transient_for(GTK_WINDOW(dialog), parent);
+    }
+   
     return dialog;
 }
 
@@ -624,16 +605,18 @@ GtkWidget *hildon_set_password_dialog_new_with_default
  * 
  * Returns current password.
  *
- * Return value: changed password ( if the dialog is successfully 
+ * Returns: changed password ( if the dialog is successfully 
  * accepted with 'OK' ( and when the check box is 'ON' ( in Change Password
  * Dialog ))
- **/
+ */
 const gchar
     *hildon_set_password_dialog_get_password(HildonSetPasswordDialog *
                                              dialog)
 {
     HildonSetPasswordDialogPrivate *priv;
 
+    g_return_val_if_fail(HILDON_IS_SET_PASSWORD_DIALOG(dialog), NULL);
+
     priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
 
     return GTK_ENTRY(priv->pwd1stEntry)->text;
@@ -643,16 +626,18 @@ const gchar
  * hildon_set_password_dialog_get_protected:
  * @dialog: pointer to HildonSetPasswordDialog
  * 
- * Returns protection mode.
+ * Returns the protection mode.
  *
- * Return value: password protection mode ( TRUE when the protection is
+ * Returns: password protection mode ( TRUE when the protection is
  *               'ON' and FALSE when the protection is 'OFF' )
- **/
+ */
 gboolean
 hildon_set_password_dialog_get_protected(HildonSetPasswordDialog * dialog)
 {
     HildonSetPasswordDialogPrivate *priv;
 
+    g_return_val_if_fail(HILDON_IS_SET_PASSWORD_DIALOG(dialog), FALSE);
+
     priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
 
     return priv->protection;
@@ -661,16 +646,18 @@ hildon_set_password_dialog_get_protected(HildonSetPasswordDialog * dialog)
 /**
  * hildon_set_password_dialog_set_domain(GtkWidget *dialog, 
  * @dialog: the dialog
- * @domain: the domain or some other descriptive text to be set.
+ * @domain: the domain or some other descriptive text to be set
  * 
- * sets the optional descriptive text
+ * Sets the optional descriptive text.
  */
 
 void hildon_set_password_dialog_set_domain(HildonSetPasswordDialog *dialog, 
-                                                gchar *domain)
+					   const gchar *domain)
 {
-  HildonSetPasswordDialogPrivate *priv =
-    HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
-  gtk_label_set_text(priv->domainLabel, domain);
-  
+  HildonSetPasswordDialogPrivate *priv = NULL;
+
+  g_return_if_fail(HILDON_IS_SET_PASSWORD_DIALOG(dialog));
+
+  priv = HILDON_SET_PASSWORD_DIALOG_GET_PRIVATE(dialog);
+  gtk_label_set_text(priv->domainLabel, domain);  
 }
