@@ -22,14 +22,13 @@
  *
  */
 
-/* 
- * @file hildon-sort-dialog.c
+/** 
+ * SECTION:hildon-sort-dialog
+ * @short_description: A widget for defining the sorting order of items
  * 
- * This file contains API for Hildon Sort dialog.
- * @desc: The sort dialog is used to define the order in which item are 
- * shown in a list. Choise lists always display the current value when 
- * the dialog is opened. 
- *
+ * HildonSortDialog is used to define an order (ascending/descending)
+ * and a field by which items are sorted in a list. The combo boxes
+ * display the current value when the dialog is opened.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,12 +37,8 @@
 
 #include <stdio.h>
 #include <libintl.h>
-
 #include <gtk/gtkcombobox.h>
 #include <gtk/gtkbox.h>
-#include <gdk/gdkkeysyms.h>
-#include <glib-object.h>
-
 #include <hildon-widgets/hildon-caption.h>
 #include "hildon-sort-dialog.h"
 
@@ -59,28 +54,30 @@ typedef struct _HildonSortDialogPrivate HildonSortDialogPrivate;
 
 static void hildon_sort_dialog_class_init(HildonSortDialogClass * class);
 static void hildon_sort_dialog_init(HildonSortDialog * widget);
+static void hildon_sort_dialog_set_property(GObject * object,
+                                     guint prop_id,
+                                     const GValue * value,
+                                     GParamSpec * pspec);
+static void hildon_sort_dialog_get_property(GObject * object,
+                                     guint prop_id,
+                                     GValue * value, GParamSpec * pspec);
+
+enum {
+    PROP_0,
+    PROP_SORT_KEY,
+    PROP_SORT_ORDER
+};
 
 /* private data */
 struct _HildonSortDialogPrivate {
-    /* Tab one */
-    GtkWidget *combo1;
-    GtkWidget *caption1;
+    /* Sort category widgets */
+    GtkWidget *combo_key;
+    GtkWidget *caption_key;
 
-    /* Tab two */
-    GtkWidget *combo2;
-    GtkWidget *caption2;
+    /* Sort order widgets */
+    GtkWidget *combo_order;
+    GtkWidget *caption_order;
 
-    /* OK/Cancel buttons */
-    GtkWidget *okButton;
-    GtkWidget *cancelButton;
-
-    /* Index value for sort_by */
-    gint sort_by_value;
-
-    /* Index value for sort_order */
-    gint sort_order_type;
-
-    gboolean index_first;
     /* Index value counter */
     gint index_counter;
 };
@@ -92,8 +89,28 @@ struct _HildonSortDialogPrivate {
  */
 static void hildon_sort_dialog_class_init(HildonSortDialogClass * class)
 {
+    GObjectClass *gobject_class = G_OBJECT_CLASS(class);
     parent_class = g_type_class_peek_parent(class);
     g_type_class_add_private(class, sizeof(HildonSortDialogPrivate));
+    
+    gobject_class->set_property = hildon_sort_dialog_set_property;
+    gobject_class->get_property = hildon_sort_dialog_get_property;
+    
+    g_object_class_install_property(gobject_class, PROP_SORT_KEY,
+        g_param_spec_int("sort-key",
+                         "Sort Key",
+                         "The currently active sort key",
+			 G_MININT,
+			 G_MAXINT,
+                         0, G_PARAM_READWRITE));
+    
+    g_object_class_install_property(gobject_class, PROP_SORT_ORDER,
+        g_param_spec_enum("sort-order",
+                         "Sort Order",
+                         "The current sorting order",
+			 GTK_TYPE_SORT_TYPE,
+                         GTK_SORT_ASCENDING,
+			 G_PARAM_READWRITE));
 }
 
 static void hildon_sort_dialog_init(HildonSortDialog * dialog)
@@ -101,11 +118,10 @@ static void hildon_sort_dialog_init(HildonSortDialog * dialog)
     HildonSortDialogPrivate *priv;
     GtkSizeGroup *group;
 
-    g_return_if_fail(HILDON_IS_SORT_DIALOG(dialog));
+    g_assert(HILDON_IS_SORT_DIALOG(dialog));
 
     priv = HILDON_SORT_DIALOG_GET_PRIVATE(dialog);
 
-    priv->index_first = TRUE;
     priv->index_counter = 0;
 
     group = GTK_SIZE_GROUP(gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL));
@@ -115,40 +131,42 @@ static void hildon_sort_dialog_init(HildonSortDialog * dialog)
     gtk_window_set_title(GTK_WINDOW(dialog), _("ckdg_ti_sort"));
 
     /* Tab one */
-    priv->combo1 = gtk_combo_box_new_text();
-    priv->caption1 = hildon_caption_new(group, _("ckdg_fi_sort_field"), priv->combo1,
+    priv->combo_key = gtk_combo_box_new_text();
+    priv->caption_key = hildon_caption_new(group, _("ckdg_fi_sort_field"), priv->combo_key,
                                         NULL, HILDON_CAPTION_OPTIONAL);
-    hildon_caption_set_separator(HILDON_CAPTION(priv->caption1), "");
+    hildon_caption_set_separator(HILDON_CAPTION(priv->caption_key), "");
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
-                       priv->caption1, FALSE, FALSE, 0);
+                       priv->caption_key, FALSE, FALSE, 0);
 
     /* Tab two */
-    priv->combo2 = gtk_combo_box_new_text();
-    gtk_combo_box_append_text(GTK_COMBO_BOX(priv->combo2),
+    priv->combo_order = gtk_combo_box_new_text();
+    gtk_combo_box_append_text(GTK_COMBO_BOX(priv->combo_order),
                               _("ckdg_va_sort_ascending"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(priv->combo2),
+    gtk_combo_box_append_text(GTK_COMBO_BOX(priv->combo_order),
                               _("ckdg_va_sort_descending"));
 
-    priv->caption2 = hildon_caption_new(group, _("ckdg_fi_sort_order"),
-                                        priv->combo2,
+    priv->caption_order = hildon_caption_new(group, _("ckdg_fi_sort_order"),
+                                        priv->combo_order,
                                         NULL, HILDON_CAPTION_OPTIONAL);
-    hildon_caption_set_separator(HILDON_CAPTION(priv->caption2), "");
+    hildon_caption_set_separator(HILDON_CAPTION(priv->caption_order), "");
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
-                       priv->caption2, FALSE, FALSE, 0);
+                       priv->caption_order, FALSE, FALSE, 0);
 
-    gtk_combo_box_set_active(GTK_COMBO_BOX(priv->combo1), 0);
-    gtk_combo_box_set_active(GTK_COMBO_BOX(priv->combo2), 0);
+    gtk_combo_box_set_active(GTK_COMBO_BOX(priv->combo_key), 0);
+    gtk_combo_box_set_active(GTK_COMBO_BOX(priv->combo_order), 0);
 
     /* Create the OK/CANCEL buttons */
-    priv->okButton = gtk_dialog_add_button(GTK_DIALOG(dialog),
+    (void) gtk_dialog_add_button(GTK_DIALOG(dialog),
                                            _("ckdg_bd_sort_dialog_ok"),
                                            GTK_RESPONSE_OK);
-    priv->cancelButton = gtk_dialog_add_button(GTK_DIALOG(dialog),
+    (void) gtk_dialog_add_button(GTK_DIALOG(dialog),
                                                _("ckdg_bd_sort_dialog_cancel"),
                                                GTK_RESPONSE_CANCEL);
-
+    /* FIXME: Hardcoded sizes are bad */
     gtk_window_resize(GTK_WINDOW(dialog), 370, 100);
     gtk_widget_show_all(GTK_DIALOG(dialog)->vbox);
+
+    g_object_unref(group); /* Captions now own their references to sizegroup */
 }
 
 /* Public functions */
@@ -159,8 +177,8 @@ static void hildon_sort_dialog_init(HildonSortDialog * dialog)
  * Returns GType for HildonSortDialog as produced by 
  * g_type_register_static().
  *
- * Return value: HildonSortDialog type
- **/
+ * Returns: HildonSortDialog type
+ */
 GType hildon_sort_dialog_get_type()
 {
     static GType dialog_type = 0;
@@ -187,11 +205,11 @@ GType hildon_sort_dialog_get_type()
 
 /**
  * hildon_sort_dialog_new:
- * @parent: Widget to be transient for, or NULL if none.
+ * @parent: widget to be transient for, or NULL if none
  *
- * HildonSortDialog contains two #HildonCaption:s with combo boxes. 
+ * HildonSortDialog contains two HildonCaptions with combo boxes. 
  *
- * Return value: pointer to a new @HildonSortDialog widget.
+ * Returns: pointer to a new @HildonSortDialog widget
  */
 GtkWidget *hildon_sort_dialog_new(GtkWindow * parent)
 {
@@ -205,11 +223,11 @@ GtkWidget *hildon_sort_dialog_new(GtkWindow * parent)
 
 /**
  * hildon_sort_dialog_get_sort_key:
- * @dialog: the #HildonSortDialog widget.
+ * @dialog: the #HildonSortDialog widget
  *
  * Gets index to currently active sort key.
  * 
- * Return value: An integer which is the index value of the "Sort by" 
+ * Returns: an integer which is the index value of the "Sort by" 
  * field 
  */
 gint hildon_sort_dialog_get_sort_key(HildonSortDialog * dialog)
@@ -221,38 +239,36 @@ gint hildon_sort_dialog_get_sort_key(HildonSortDialog * dialog)
 
     priv = HILDON_SORT_DIALOG_GET_PRIVATE(dialog);
     
-    combo_key = gtk_bin_get_child(GTK_BIN(priv->caption1));
-    priv->sort_by_value =
-        gtk_combo_box_get_active(GTK_COMBO_BOX(combo_key));
-    return priv->sort_by_value;
+    combo_key = gtk_bin_get_child(GTK_BIN(priv->caption_key));
+        
+    return gtk_combo_box_get_active(GTK_COMBO_BOX(combo_key));
 }
 
 /**
  * hildon_sort_dialog_get_sort_order:
- * @dialog: the #HildonSortDialog widget.
+ * @dialog: the #HildonSortDialog widget
  *
  * Gets current sorting order from "Sort order" field.
  *
- * Return value: current sorting order as #GtkSortType.
+ * Returns: current sorting order as #GtkSortType
  */
 GtkSortType hildon_sort_dialog_get_sort_order(HildonSortDialog * dialog)
 {
-    GtkWidget *combo_key;
+    GtkWidget *combo_order;
     HildonSortDialogPrivate *priv;
 
     g_return_val_if_fail(HILDON_IS_SORT_DIALOG(dialog), 0);
 
     priv = HILDON_SORT_DIALOG_GET_PRIVATE(dialog);
-    combo_key = gtk_bin_get_child(GTK_BIN(priv->caption2));
-    priv->sort_order_type =
-        gtk_combo_box_get_active(GTK_COMBO_BOX(combo_key));
-    return priv->sort_order_type;
+    combo_order = gtk_bin_get_child(GTK_BIN(priv->caption_order));
+        
+    return gtk_combo_box_get_active(GTK_COMBO_BOX(combo_order));
 }
 
 /**
  * hildon_sort_dialog_set_sort_key:
- * @dialog: the #HildonSortDialog widget.
- * @key: Combo box's index value.
+ * @dialog: the #HildonSortDialog widget
+ * @key: combo box's index value
  *
  * Sets the index value of the #HildonSortDialog widget.
  */
@@ -264,14 +280,16 @@ void hildon_sort_dialog_set_sort_key(HildonSortDialog * dialog, gint key)
     g_return_if_fail(HILDON_IS_SORT_DIALOG(dialog));
 
     priv = HILDON_SORT_DIALOG_GET_PRIVATE(dialog);
-    combo_key = gtk_bin_get_child(GTK_BIN(priv->caption1));
+    combo_key = gtk_bin_get_child(GTK_BIN(priv->caption_key));
     gtk_combo_box_set_active(GTK_COMBO_BOX(combo_key), key);
+
+    g_object_notify (G_OBJECT (dialog), "sort-key");
 }
 
 /**
  * hildon_sort_dialog_set_sort_order:
- * @dialog: the #HildonSortDialog widget.
- * @order: Combo box's index value.
+ * @dialog: the #HildonSortDialog widget
+ * @order: combo box's index value
  *
  * Sets the index value of the #HildonSortDialog widget.
  */
@@ -285,20 +303,22 @@ hildon_sort_dialog_set_sort_order(HildonSortDialog * dialog,
     g_return_if_fail(HILDON_IS_SORT_DIALOG(dialog));
 
     priv = HILDON_SORT_DIALOG_GET_PRIVATE(dialog);
-    combo_order = gtk_bin_get_child(GTK_BIN(priv->caption2));
+    combo_order = gtk_bin_get_child(GTK_BIN(priv->caption_order));
     gtk_combo_box_set_active(GTK_COMBO_BOX(combo_order), order);
+
+    g_object_notify (G_OBJECT (dialog), "sort-order");
 }
 
 /**
  * hildon_sort_dialog_add_sort_key:
- * @dialog: the #HildonSortDialog widget.
- * @sort_key: Combo box's index value
+ * @dialog: the #HildonSortDialog widget
+ * @sort_key: combo box's index value
  *
  * Adds a new sort key and returns the respective index in
  * sort key combobox.
  *
- * Return value: An integer which is the index of the added combo box's
- * item.
+ * Returns: an integer which is the index of the added combo box's
+ * item
  */
 gint
 hildon_sort_dialog_add_sort_key(HildonSortDialog * dialog,
@@ -309,13 +329,51 @@ hildon_sort_dialog_add_sort_key(HildonSortDialog * dialog,
     g_return_val_if_fail(HILDON_IS_SORT_DIALOG(dialog), -1);
 
     priv = HILDON_SORT_DIALOG_GET_PRIVATE(dialog);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(priv->combo1), sort_key);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(priv->combo_key), sort_key);
 
-    if (priv->index_first == TRUE) {
-        priv->index_first = FALSE;
-        return priv->index_counter;
+    return priv->index_counter++;
+}
 
-    } else {
-        return priv->index_counter += 1;
+static void
+hildon_sort_dialog_set_property(GObject * object,
+                         guint prop_id,
+                         const GValue * value, GParamSpec * pspec)
+{
+    HildonSortDialog *dialog;
+
+    dialog = HILDON_SORT_DIALOG(object);
+
+    switch (prop_id) {
+    case PROP_SORT_KEY:
+        hildon_sort_dialog_set_sort_key(dialog, g_value_get_int(value));
+        break;
+    case PROP_SORT_ORDER:
+        hildon_sort_dialog_set_sort_order(dialog, g_value_get_enum(value));
+        break;
+    default:
+        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
+        break;
     }
 }
+
+static void
+hildon_sort_dialog_get_property(GObject * object,
+                         guint prop_id, GValue * value, GParamSpec * pspec)
+{
+    HildonSortDialog *dialog;
+
+    dialog = HILDON_SORT_DIALOG(object);
+
+    switch (prop_id) {
+    case PROP_SORT_KEY:
+        g_value_set_int(value, hildon_sort_dialog_get_sort_key(dialog));
+        break;
+    case PROP_SORT_ORDER:
+        g_value_set_enum(value, hildon_sort_dialog_get_sort_order(dialog));
+        break;
+    default:
+        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
+        break;
+    }
+}
+
