@@ -22,12 +22,14 @@
  *
  */
 
-/**
- * @file hildon-vvolumebar.c
+/*
+ * SECTION:hildon-vvolumebar
+ * @short_description: A widget that displays a vertical volume bar
+ * @see_also: #HildonVolumebar, #HildonHVolumebar
  *
- * This file contains the implementation of HildonVVolumebar.
- * This widget is a subclass of HildonVolumebar and implements
- * horizontal version of Volumebar.
+ * #HildonVVolumebar is a subclass of #HildonVolumebar.  It displays a
+ * vertical volume bar that allows increasing or decreasing volume
+ * within a predefined range, and muting when users click the mute icon.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,23 +38,23 @@
 
 #include <gtk/gtk.h>
 #include "hildon-vvolumebar.h"
-#include "hildon-volumebar.h"
 #include "hildon-volumebar-range.h"
 #include "hildon-volumebar-private.h"
 
+/* Volume bar */
 #define DEFAULT_BAR_WIDTH               58
 #define MINIMUM_BAR_HEIGHT             165
+/* Toggle button */
 #define DEFAULT_VERTICAL_TBUTTON_WIDTH  26
 #define DEFAULT_VERTICAL_TBUTTON_HEIGHT 26
 #define DEFAULT_ENDING_SIZE             20
+/* Gap to leave for mute button */
 #define HORIZONTAL_MUTE_GAP             16
 #define VERTICAL_MUTE_GAP                6
 
 static HildonVolumebarClass *parent_class;
-static void vvolumebar_class_init(HildonVVolumebarClass * klass);
-static void vvolumebar_init(HildonVVolumebar * vvolumebar);
-static void hildon_vvolumebar_mute(GtkWidget * widget,
-                                   HildonVVolumebar * self);
+static void hildon_vvolumebar_class_init(HildonVVolumebarClass * klass);
+static void hildon_vvolumebar_init(HildonVVolumebar * vvolumebar);
 static gboolean hildon_vvolumebar_expose(GtkWidget * widget,
                                          GdkEventExpose * event);
 static void hildon_vvolumebar_size_request(GtkWidget * widget,
@@ -69,12 +71,12 @@ GType hildon_vvolumebar_get_type(void)
             sizeof(HildonVVolumebarClass),
             NULL,       /* base_init */
             NULL,       /* base_finalize */
-            (GClassInitFunc) vvolumebar_class_init,     /* class_init */
+            (GClassInitFunc) hildon_vvolumebar_class_init,     /* class_init */
             NULL,       /* class_finalize */
             NULL,       /* class_data */
             sizeof(HildonVVolumebar),
             0,
-            (GInstanceInitFunc) vvolumebar_init,
+            (GInstanceInitFunc) hildon_vvolumebar_init,
         };
         type =
             g_type_register_static(HILDON_TYPE_VOLUMEBAR,
@@ -83,7 +85,7 @@ GType hildon_vvolumebar_get_type(void)
     return type;
 }
 
-static void vvolumebar_class_init(HildonVVolumebarClass * klass)
+static void hildon_vvolumebar_class_init(HildonVVolumebarClass * klass)
 {
     GtkWidgetClass *volumebar_class = GTK_WIDGET_CLASS(klass);
 
@@ -94,24 +96,20 @@ static void vvolumebar_class_init(HildonVVolumebarClass * klass)
     volumebar_class->expose_event = hildon_vvolumebar_expose;
 }
 
-static void vvolumebar_init(HildonVVolumebar * vvolumebar)
+static void hildon_vvolumebar_init(HildonVVolumebar * vvolumebar)
 {
-    HildonVolumebar *v_ptr = HILDON_VOLUMEBAR(vvolumebar);
     HildonVolumebarPrivate *priv;
 
     priv = HILDON_VOLUMEBAR_GET_PRIVATE(vvolumebar);
 
-    priv->ownorientation = GTK_ORIENTATION_VERTICAL;
-    priv->orientation = GTK_ORIENTATION_VERTICAL;
-
     priv->volumebar =
         HILDON_VOLUMEBAR_RANGE(hildon_volumebar_range_new
                                (GTK_ORIENTATION_VERTICAL));
 
     GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(vvolumebar), GTK_CAN_FOCUS);
 
-    gtk_widget_set_parent(GTK_WIDGET(priv->tbutton), GTK_WIDGET(v_ptr));
-    gtk_widget_set_parent(GTK_WIDGET(priv->volumebar), GTK_WIDGET(v_ptr));
+    gtk_widget_set_parent(GTK_WIDGET(priv->tbutton), GTK_WIDGET(vvolumebar));
+    gtk_widget_set_parent(GTK_WIDGET(priv->volumebar), GTK_WIDGET(vvolumebar));
 
     gtk_scale_set_draw_value(GTK_SCALE(priv->volumebar), FALSE);
 
@@ -119,9 +117,8 @@ static void vvolumebar_init(HildonVVolumebar * vvolumebar)
     g_signal_connect_swapped(G_OBJECT(priv->volumebar), "value-changed",
                              G_CALLBACK(hildon_volumebar_level_change),
                              vvolumebar);
-    g_signal_connect(G_OBJECT(priv->tbutton), "toggled",
-                     G_CALLBACK(hildon_vvolumebar_mute), vvolumebar);
-    /* end here */
+    g_signal_connect_swapped(priv->tbutton, "toggled",
+        G_CALLBACK(_hildon_volumebar_mute_toggled), vvolumebar);
 
     gtk_widget_show(GTK_WIDGET(priv->volumebar));
 }
@@ -131,9 +128,9 @@ static void vvolumebar_init(HildonVVolumebar * vvolumebar)
  *
  * Creates a new #HildonVVolumebar widget.
  *
- * Returns: a new #HildonVVolumebar.
+ * Returns: a new #HildonVVolumebar
  */
-GtkWidget *hildon_vvolumebar_new()
+GtkWidget *hildon_vvolumebar_new(void)
 {
     return GTK_WIDGET(g_object_new(HILDON_TYPE_VVOLUMEBAR, NULL));
 }
@@ -142,9 +139,13 @@ static gboolean hildon_vvolumebar_expose(GtkWidget * widget,
                                          GdkEventExpose * event)
 {
     HildonVolumebarPrivate *priv;
+
+    g_assert(HILDON_IS_VVOLUMEBAR(widget));
+
     priv = HILDON_VOLUMEBAR_GET_PRIVATE(HILDON_VOLUMEBAR(widget));
     
     if (GTK_WIDGET_DRAWABLE(widget)) {
+        /* Paint background */
         gtk_paint_box(widget->style, widget->window,
                       GTK_WIDGET_STATE(priv->volumebar), GTK_SHADOW_OUT,
                       NULL, widget, "background",
@@ -153,6 +154,7 @@ static gboolean hildon_vvolumebar_expose(GtkWidget * widget,
                       widget->allocation.width,
                       widget->allocation.height);
 
+	/* The contents of the widget can paint themselves */
         (*GTK_WIDGET_CLASS(parent_class)->expose_event) (widget, event);
     }
 
@@ -163,6 +165,8 @@ static void
 hildon_vvolumebar_size_request(GtkWidget * widget,
                                GtkRequisition * requisition)
 {
+    g_assert(HILDON_IS_VVOLUMEBAR(widget));
+
     requisition->height = MINIMUM_BAR_HEIGHT;
     requisition->width = DEFAULT_BAR_WIDTH;
 }
@@ -171,14 +175,15 @@ static void
 hildon_vvolumebar_size_allocate(GtkWidget * widget,
                                 GtkAllocation * allocation)
 {
-    HildonVolumebar *vbar;
     HildonVolumebarPrivate *priv;
 
     GtkAllocation range_allocation, button_allocation;
 
-    vbar = HILDON_VOLUMEBAR(widget);
-    priv = HILDON_VOLUMEBAR_GET_PRIVATE(vbar);
+    g_assert(HILDON_IS_VVOLUMEBAR(widget));
 
+    priv = HILDON_VOLUMEBAR_GET_PRIVATE(widget);
+
+    /* Center the widget horizontally */
     if (allocation->width > DEFAULT_BAR_WIDTH) {
         allocation->x +=
 	  (allocation->width - DEFAULT_BAR_WIDTH) / 2;
@@ -188,6 +193,7 @@ hildon_vvolumebar_size_allocate(GtkWidget * widget,
     widget->allocation = *allocation;
 
     if (priv->volumebar && GTK_WIDGET_VISIBLE(priv->volumebar)) {
+        /* Allocate space for the slider */
         range_allocation.x = allocation->x;
         range_allocation.y = allocation->y + DEFAULT_ENDING_SIZE;
 
@@ -195,6 +201,7 @@ hildon_vvolumebar_size_allocate(GtkWidget * widget,
         
         if (priv->tbutton && GTK_WIDGET_VISIBLE(priv->tbutton))
         {
+	    /* Leave room for the mute button */
             range_allocation.height = MAX(0,
                                           allocation->height
                                           - 2 * DEFAULT_ENDING_SIZE
@@ -214,6 +221,7 @@ hildon_vvolumebar_size_allocate(GtkWidget * widget,
     }
     
     if (priv->tbutton && GTK_WIDGET_VISIBLE(priv->tbutton)) {
+        /* Allocate space for the mute button */
         button_allocation.x = allocation->x + HORIZONTAL_MUTE_GAP;
         button_allocation.y = allocation->y + allocation->height -
                               VERTICAL_MUTE_GAP - 2 * DEFAULT_ENDING_SIZE;
@@ -223,9 +231,3 @@ hildon_vvolumebar_size_allocate(GtkWidget * widget,
                                  &button_allocation);
     }
 }
-
-static void
-hildon_vvolumebar_mute(GtkWidget * widget, HildonVVolumebar * self)
-{
-    g_signal_emit_by_name(GTK_WIDGET(self), "mute_toggled");
-}
