@@ -22,21 +22,21 @@
  *
  */
 
-/*
- * TODO:
- * - Must check if graphics should be added to widgets weekday
- *   buttons
+/**
+ * SECTION:hildon-weekday-picker
+ * @short_description: A widget for picking days on which a certain event 
+ * should take place
+ * @see_also: #HildonWeekdayPicker 
  *
- */
-
-/* HILDON DOC
- * @shortdesc: Weekday Picker is a widget for selecting weekdays
- * @longdesc: Weekday Picker is a widget for selecting weekdays. 
- * It shows seven toggle buttons that can have state on or off.
- *
- * @seealso: #HildonTimePicker
- */
-
+ * #HildonWeekdayPicker supports non-mutually exclusive selection of days of 
+ * the week. Selected days of the week are shown with a pushed-in effect.
+ * 
+ * #HildonWeekdayPicker is used where users are required to pick days on which 
+ * a certain event should take place, for example, which days a Calendar event 
+ * should be repeated on. It is used in Calendar in the Repeat dialog, in Tasks 
+ * in the Repeat dialog and in the Email set-up wizard.
+ */  
+ 
  /* GDate numbers days from 1 to 7 and G_DATE_MONDAY is 1st day. However
     according to locale settings first day is sunday. To get around this
     problem, we addjust GDate days numbering to be same as locale
@@ -61,11 +61,9 @@
 #include "hildon-weekday-picker.h"
 #include "hildon-composite-widget.h"
 
-#define _(string) dgettext(PACKAGE, string)
-
 #define HILDON_WEEKDAY_PICKER_GET_PRIVATE(obj) \
     (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
-     HILDON_WEEKDAY_PICKER_TYPE, HildonWeekdayPickerPrivate));
+     HILDON_TYPE_WEEKDAY_PICKER, HildonWeekdayPickerPrivate));
 
 static GtkContainerClass *parent_class;
 
@@ -73,38 +71,27 @@ typedef struct _HildonWeekdayPickerPrivate HildonWeekdayPickerPrivate;
 
 static void
 hildon_weekday_picker_class_init(HildonWeekdayPickerClass * picker_class);
-
 static void 
 hildon_weekday_picker_init(HildonWeekdayPicker * picker);
-
 static void
 hildon_weekday_picker_size_allocate(GtkWidget * widget,
                                     GtkAllocation * allocation);
-
 static void
 hildon_weekday_picker_size_request(GtkWidget * widget,
                                    GtkRequisition * requisition);
-
 static void
 hildon_weekday_picker_forall(GtkContainer * container,
                              gboolean include_internals,
                              GtkCallback callback, gpointer callback_data);
-
 static void
 hildon_weekday_picker_destroy(GtkObject * self);
 
-static gboolean
-hildon_weekday_picker_mnemonic_activate(GtkWidget *widget,
-                                        gboolean group_cycling);
-
 static void
-button_toggle(GtkToggleButton * togglebutton, gpointer data);
+button_toggle(GtkToggleButton * togglebutton, gpointer wpicker);
 
 struct _HildonWeekdayPickerPrivate {
-    guint dayorder[8];  /* Lookup table for weekdays */
-    GtkWidget *buttons[8];      /* weekday buttons */
-    guint days;
-    guint last_index;
+    GtkWidget *buttons[8];           /* weekday buttons in show order */
+    GtkWidget *day_order_buttons[8]; /* weekday buttons in glib day order */
 };
 
 enum {
@@ -149,7 +136,7 @@ hildon_weekday_picker_class_init(HildonWeekdayPickerClass * picker_class)
     g_type_class_add_private(picker_class,
                              sizeof(HildonWeekdayPickerPrivate));
 
-    widget_class->mnemonic_activate = hildon_weekday_picker_mnemonic_activate;
+    /* Override virtual methods */
     widget_class->size_request = hildon_weekday_picker_size_request;
     widget_class->size_allocate = hildon_weekday_picker_size_allocate;
     widget_class->focus = hildon_composite_widget_focus;
@@ -157,6 +144,7 @@ hildon_weekday_picker_class_init(HildonWeekdayPickerClass * picker_class)
     GTK_OBJECT_CLASS(picker_class)->destroy =
         hildon_weekday_picker_destroy;
 
+    /* Create a signal for reporting user actions */
     signals[SELECTION_CHANGED_SIGNAL] = g_signal_new("selection_changed",
                                                 G_OBJECT_CLASS_TYPE
                                                 (object_class),
@@ -174,32 +162,38 @@ hildon_weekday_picker_init(HildonWeekdayPicker * picker)
 {
     HildonWeekdayPickerPrivate *priv;
     gint i, day;
-    const gchar *wdays[8];
+    /* weekday indexes to be used with nl_langinfo. These are shifted
+     * by one for glib compability */
+    int wdays[] = {
+	-1,        /* 0 = invalid date */
+	ABDAY_2,   /* 1 = monday    in glib */
+	ABDAY_3,   /* 2 = tuesday   in glib */
+	ABDAY_4,   /* 3 = wednesday in glib */
+	ABDAY_5,   /* 4 = thursday  in glib */
+	ABDAY_6,   /* 5 = friday    in glib */
+	ABDAY_7,   /* 6 = saturday  in glib */
+	ABDAY_1 }; /* 7 = sunday    in glib */
     GtkSizeGroup *sgroup;
 
     sgroup = gtk_size_group_new(GTK_SIZE_GROUP_BOTH);
 
-    /* NOTE: we query locales with "first_weekday" parameter, but this
-       seems to be broken on some installations. e.g. on my system I
-       receive "1" (Sunday) to be first day of the week on "fi_FI"
-       locale, when it should be "2" (Monday). */
-
     /* Check our first weekday */
-    day = *nl_langinfo(_NL_TIME_FIRST_WEEKDAY);
-
-    wdays[1] = nl_langinfo(ABDAY_1);
-    wdays[2] = nl_langinfo(ABDAY_2);
-    wdays[3] = nl_langinfo(ABDAY_3);
-    wdays[4] = nl_langinfo(ABDAY_4);
-    wdays[5] = nl_langinfo(ABDAY_5);
-    wdays[6] = nl_langinfo(ABDAY_6);
-    wdays[7] = nl_langinfo(ABDAY_7);
+    day = *nl_langinfo(_NL_TIME_FIRST_WEEKDAY); 
 
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
+    
+    /* Shift the days by one. This is done because GDateWeekday 
+     * starts with Monday(1) and langinfo's first day is Sunday */
+    day--;
+    if (day < 1)
+        day = 7;
 
+    /* Initialize and pack day buttons */
     for (i = 1; i <= 7; i++) {
-        priv->buttons[i] = gtk_toggle_button_new_with_label(wdays[day]);
-        priv->dayorder[i] = day++;
+        priv->buttons[i] = 
+	    gtk_toggle_button_new_with_label(nl_langinfo(wdays[day]));
+	priv->day_order_buttons[day] = priv->buttons[i];
+        day++;
 
         if (day > 7)
             day = 1;
@@ -207,7 +201,6 @@ hildon_weekday_picker_init(HildonWeekdayPicker * picker)
         g_signal_connect(GTK_WIDGET(priv->buttons[i]),
                          "toggled", G_CALLBACK(button_toggle), picker);
 
-        priv->last_index = i;
         gtk_size_group_add_widget(sgroup, priv->buttons[i]);
 
         gtk_widget_set_parent(priv->buttons[i], GTK_WIDGET(picker));
@@ -215,6 +208,8 @@ hildon_weekday_picker_init(HildonWeekdayPicker * picker)
     }
 
     GTK_WIDGET_SET_FLAGS(picker, GTK_NO_WINDOW);
+
+    g_object_unref( sgroup );
 }
 
 /**
@@ -222,20 +217,11 @@ hildon_weekday_picker_init(HildonWeekdayPicker * picker)
  *
  * Creates a new #HildonWeekdayPicker.
  *
- * Return value: Pointer to a new @HildonWeekdayPicker widget.
+ * Returns: pointer to a new #HildonWeekdayPicker widget.
  */
 GtkWidget *hildon_weekday_picker_new(void)
 {
-    return g_object_new(HILDON_WEEKDAY_PICKER_TYPE, NULL);
-}
-
-static gboolean
-hildon_weekday_picker_mnemonic_activate(GtkWidget *widget,
-                                        gboolean group_cycling)
-{
-  HildonWeekdayPickerPrivate *priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(widget);
-  gtk_widget_grab_focus(priv->buttons[1]);
-  return TRUE;
+    return g_object_new(HILDON_TYPE_WEEKDAY_PICKER, NULL);
 }
 
 static void 
@@ -247,15 +233,17 @@ hildon_weekday_picker_forall(GtkContainer * container,
     HildonWeekdayPickerPrivate *priv;
     gint i;
 
-    g_return_if_fail(container);
-    g_return_if_fail(callback);
+    g_assert(container);
+    g_assert(callback);
 
     picker = HILDON_WEEKDAY_PICKER(container);
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
 
+    /* We only have internal children */
     if (!include_internals)
         return;
 
+    /* Activate callback for each day button */
     for (i = 1; i <= 7; ++i) {
         (*callback) (priv->buttons[i], callback_data);
     }
@@ -270,6 +258,7 @@ hildon_weekday_picker_destroy(GtkObject * self)
 
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(self);
 
+    /* Destroy internal children... */
     for (i = 1; i <= 7; ++i) {
       if (priv->buttons[i])
       {
@@ -278,6 +267,7 @@ hildon_weekday_picker_destroy(GtkObject * self)
       }
     }
 
+    /* ... and chain to parent. */
     if (GTK_OBJECT_CLASS(parent_class)->destroy)
         GTK_OBJECT_CLASS(parent_class)->destroy(self);
 
@@ -297,6 +287,8 @@ hildon_weekday_picker_size_request(GtkWidget * widget,
     requisition->width = 0;
     requisition->height = 0;
 
+    /* Request an area that is as wide as all of the buttons
+       together and tall enough to hold heightest button */
     for (i = 1; i <= 7; ++i) {
         gtk_widget_size_request(priv->buttons[i], &req);
         requisition->width += req.width;
@@ -319,8 +311,8 @@ hildon_weekday_picker_size_allocate(GtkWidget * widget,
     guint sval;
     GtkTextDirection direction;
 
-    g_return_if_fail(widget);
-    g_return_if_fail(allocation);
+    g_assert(widget);
+    g_assert(allocation);
 
     /* Check orientation */
     direction = gtk_widget_get_direction(widget);
@@ -334,6 +326,8 @@ hildon_weekday_picker_size_allocate(GtkWidget * widget,
         sval = 1;
     else
         sval = 7;
+
+    /* Allocate day buttons side by side honouring the text direction */
     for (i = 1; i <= 7; ++i) {
         gtk_widget_get_child_requisition(priv->buttons[sval],
                                          &child_requisition);
@@ -352,24 +346,22 @@ hildon_weekday_picker_size_allocate(GtkWidget * widget,
 }
 
 static void
-button_toggle(GtkToggleButton * button, gpointer data)
+button_toggle(GtkToggleButton * button, gpointer wpicker)
 {
     HildonWeekdayPicker *picker;
     HildonWeekdayPickerPrivate *priv;
     gint i;
-    static guint wdays[] = { 1, 2, 4, 8, 16, 32, 64, 128 };
 
-    g_return_if_fail(button);
-    g_return_if_fail(data);
+    g_assert(button);
+    g_assert(wpicker);
 
-    picker = HILDON_WEEKDAY_PICKER(data);
+    picker = HILDON_WEEKDAY_PICKER(wpicker);
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
 
     for (i = 1; i <= 7; ++i) {
-        if (GTK_WIDGET(button) == priv->buttons[i]) {
-            priv->days ^= wdays[i];
-            g_signal_emit (GTK_WIDGET(picker), signals[SELECTION_CHANGED_SIGNAL],
-                   0, priv->dayorder[i]);
+        if (GTK_WIDGET(button) == priv->day_order_buttons[i]) {
+            g_signal_emit (GTK_WIDGET(picker), 
+			   signals[SELECTION_CHANGED_SIGNAL], 0, i);
             break;
         }
     }
@@ -377,188 +369,134 @@ button_toggle(GtkToggleButton * button, gpointer data)
 
 /**
  * hildon_weekday_picker_set_day:
- * @picker: the @HildonWeekdayPicker widget
- * @day: Day to be set
+ * @picker: the #HildonWeekdayPicker widget
+ * @day: day to be set active
  *
- * Select specified weekday.
+ * Sets specified weekday active.
  */
 void 
 hildon_weekday_picker_set_day(HildonWeekdayPicker * picker,
-                                   GDateWeekday day)
+			      GDateWeekday day)
 {
     HildonWeekdayPickerPrivate *priv;
-    static guint wdays[] = { 1, 2, 4, 8, 16, 32, 64, 128 };
-    guint i;
 
     g_return_if_fail(picker);
-    g_return_if_fail(day >= 1 && day <= 7);
+    g_return_if_fail(g_date_valid_weekday(day));
 
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
 
-    if (day == G_DATE_SUNDAY)
-        day = G_DATE_MONDAY;
-    else
-        day++;
-
-    for (i = 1; i <= 7; i++) {
-        if (priv->dayorder[i] == day) {
-            if (!(priv->days & wdays[i]))
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-                                             (priv->buttons[i]), TRUE);
-        }
-    }
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				 (priv->day_order_buttons[day]), TRUE);
 }
 
 /**
  * hildon_weekday_picker_unset_day:
- * @picker: the @HildonWeekdayPicker widget
- * @day: Day to be unset
+ * @picker: the #HildonWeekdayPicker widget
+ * @day: day to be set inactive 
  *
- * Unselect specified weekday.
+ * Sets specified weekday inactive.
  */
 void 
 hildon_weekday_picker_unset_day(HildonWeekdayPicker * picker,
-                                     GDateWeekday day)
+				GDateWeekday day)
 {
     HildonWeekdayPickerPrivate *priv;
-    static guint wdays[] = { 1, 2, 4, 8, 16, 32, 64, 128 };
-    guint i;
 
     g_return_if_fail(picker);
-    g_return_if_fail(day >= 1 && day <= 7);
+    g_return_if_fail(g_date_valid_weekday(day));
 
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
 
-    if (day == G_DATE_SUNDAY)
-        day = G_DATE_MONDAY;
-    else
-        day++;
-
-    for (i = 1; i <= 7; i++) {
-        if (priv->dayorder[i] == day) {
-            if (priv->days & wdays[i])
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-                                             (priv->buttons[i]), FALSE);
-        }
-    }
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				 (priv->day_order_buttons[day]), FALSE);
 }
 
 /**
  * hildon_weekday_picker_toggle_day:
- * @picker: the @HildonWeekdayPicker widget
- * @day: Day to be toggled
+ * @picker: the #HildonWeekdayPicker widget
+ * @day: day to be toggled
  *
- * Toggle current status of the specified weekday.
+ * Toggles current status of the specified weekday.
  */
 void 
 hildon_weekday_picker_toggle_day(HildonWeekdayPicker * picker,
-                                      GDateWeekday day)
+				 GDateWeekday day)
 {
     HildonWeekdayPickerPrivate *priv;
-    guint i;
-    gboolean is_active;
    
     g_return_if_fail(picker);
-    g_return_if_fail(day >= 1 && day <= 7);
+    g_return_if_fail(g_date_valid_weekday(day));
 
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
 
-    if (day == G_DATE_SUNDAY)
-        day = G_DATE_MONDAY;
-    else
-        day++;
-
-    for (i = 1; i <= 7; i++) {
-        if (priv->dayorder[i] == day) {
-            is_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-					(priv->buttons[i]));
-            gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-                                         (priv->buttons[i]),
-                                         is_active ? FALSE : TRUE);
-        }
-    }
+    gtk_toggle_button_set_active(
+	GTK_TOGGLE_BUTTON(priv->day_order_buttons[day]), 
+	!gtk_toggle_button_get_active(
+	    GTK_TOGGLE_BUTTON(priv->day_order_buttons[day])));
 }
 
 /**
  * hildon_weekday_picker_set_all:
- * @picker: the @HildonWeekdayPicker widget
+ * @picker: the #HildonWeekdayPicker widget
  *
- * Set all weekdays.
+ * Sets all weekdays active.
  */
 void 
 hildon_weekday_picker_set_all(HildonWeekdayPicker * picker)
 {
     HildonWeekdayPickerPrivate *priv;
     gint i;
-    static guint wdays[] = { 1, 2, 4, 8, 16, 32, 64, 128 };
 
     g_return_if_fail(picker);
 
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
 
-    for (i = 1; i <= 7; i++) {
-        if (!(priv->days & wdays[i]))
-            gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-                                         (priv->buttons[i]), TRUE);
-    }
+    for (i = 1; i <= 7; i++)
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->buttons[i]), 
+				     TRUE);
 }
 
 /**
  * hildon_weekday_picker_unset_all:
- * @picker: the @HildonWeekdayPicker widget
+ * @picker: the #HildonWeekdayPicker widget
  *
- * Unset all weekdays.
+ * Sets all weekdays inactive.
  */
 void 
 hildon_weekday_picker_unset_all(HildonWeekdayPicker * picker)
 {
     HildonWeekdayPickerPrivate *priv;
     gint i;
-    static guint wdays[] = { 1, 2, 4, 8, 16, 32, 64, 128 };
 
     g_return_if_fail(picker);
 
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
 
-    for (i = 1; i <= 7; i++) {
-        if (priv->days & wdays[i])
-            gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-                                         (priv->buttons[i]), FALSE);
-    }
+    for (i = 1; i <= 7; i++)
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->buttons[i]),
+				     FALSE);
 }
 
 /**
- * hildon_weekday_picker_set_all:
- * @picker: the @HildonWeekdayPicker widget
- * @day: Day to be checked.
+ * hildon_weekday_picker_isset_day:
+ * @picker: the #HildonWeekdayPicker widget
+ * @day: day to be checked.
  *
- * Check if the specified weekday is set.
+ * Checks if the specified weekday is set active.
  *
- * Return value: TRUE if the day is set. 
+ * Returns: TRUE if the day is set, FALSE if the day is not set
  */
 gboolean 
 hildon_weekday_picker_isset_day(HildonWeekdayPicker * picker,
-                                         GDateWeekday day)
+				GDateWeekday day)
 {
     HildonWeekdayPickerPrivate *priv;
-    guint i;
 
     g_return_val_if_fail(picker, FALSE);
-    g_return_val_if_fail(day >= 1 && day <= 7, FALSE);
+    g_return_val_if_fail(g_date_valid_weekday(day), FALSE);
 
     priv = HILDON_WEEKDAY_PICKER_GET_PRIVATE(picker);
 
-    if (day == G_DATE_SUNDAY)
-        day = G_DATE_MONDAY;
-    else
-        day++;
-
-    for (i = 1; i <= 7; i++) {
-        if ( priv->dayorder[i] == day && 
-             gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
-                                         (priv->buttons[i]))) {
-             return TRUE;
-        }
-    }
-    return FALSE;
+    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+					    priv->day_order_buttons[day]));
 }
